﻿using System;
using System.Windows;
using Telerik.Windows.Controls.Docking;

namespace Docking_RestrictToolWindows
{
	public class RestrictToolWindow
	{
		public static bool GetIsRestricted(DependencyObject obj)
		{
			return (bool)obj.GetValue(IsRestrictedProperty);
		}

		public static void SetIsRestricted(DependencyObject obj, bool value)
		{
			obj.SetValue(IsRestrictedProperty, value);
		}

		public static readonly DependencyProperty IsRestrictedProperty =
			DependencyProperty.RegisterAttached("IsRestricted", typeof(bool), typeof(RestrictToolWindow), new PropertyMetadata(OnIsRestrictedChanged));

		private static void OnIsRestrictedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
		{
			var toolWindow = d as ToolWindow;

			if (toolWindow != null)
			{
				if ((bool)(e.NewValue))
				{
					toolWindow.LayoutChangeEnded += OnToolWindowLayoutChangeEnded;
				}
				else
				{
					toolWindow.LayoutChangeEnded -= OnToolWindowLayoutChangeEnded;
				}
			}
		}

		private static void OnToolWindowLayoutChangeEnded(object sender, EventArgs e)
		{
			var window = sender as ToolWindow;

			window.HorizontalOffset = Math.Max(0, Math.Min(Application.Current.RootVisual.RenderSize.Width - window.Width, window.HorizontalOffset));
			window.VerticalOffset = Math.Max(0, Math.Min(Application.Current.RootVisual.RenderSize.Height - window.Height, window.VerticalOffset));
		}
	}
}
